@@ -1,25 +1,25 @@
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
 import pkg_resources
 import click
@@ -42,6 +42,7 @@ from . import common
     default=None,
     help="Enable remote debugging with rfoo on the given PORT",
 )
+@common.settings_files
 @click.version_option(version=taurus.Release.version)
 def taurus_cmd(
     log_level,
@@ -49,12 +50,17 @@ def taurus_cmd(
     serialization_mode,
     default_formatter,
     rconsole_port,
+    settings_files,
 ):
     """The main taurus command"""
 
     # set log level
     taurus.setLogLevel(getattr(taurus, log_level))
 
+    if settings_files:
+        from taurus.tauruscustomsettings import load_configs
+
+        load_configs(settings_files)
     # set polling period
     if polling_period is not None:
         taurus.changeDefaultPollingPeriod(polling_period)
@@ -98,20 +104,6 @@ def register_subcommands():
             subcommand = ep.load()
             taurus_cmd.add_command(subcommand)
         except Exception as e:
-            # -----------------------------------------------------------
-            # Use info instead of warning in case of nonimportable Qwt5
-            # (e.g. when using py3 or Qt5) to avoid spam
-            # This special case can be removed when taurus.qt.qtgui.qwt5
-            # is moved to a separate plugin, since the entry point will
-            # be registered only if the plugin is installed
-            if ep.name == "qwt5":
-                taurus.info(
-                    'Cannot add "%s" subcommand to taurus. Reason: %r',
-                    ep.name,
-                    e,
-                )
-                continue
-            # -----------------------------------------------------------
             taurus.warning(
                 'Cannot add "%s" subcommand to taurus. Reason: %r', ep.name, e
             )
