@@ -1,27 +1,27 @@
 #!/usr/bin/env python
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
 """
 Tango extension for taurus core mode.
@@ -103,14 +103,52 @@ Finally, the TangoFactory object can be accessed as::
           issue warnings if detected.
 """
 
-from __future__ import absolute_import
-
-from .enums import *
-from .tangodatabase import *
-from .tangodevice import *
-from .tangofactory import *
-from .tangoattribute import *
-from .tangoconfiguration import *
+from .enums import (
+    TangoObjectType,
+    EVENT_TO_POLLING_EXCEPTIONS,
+    FROM_TANGO_TO_NUMPY_TYPE,
+    FROM_TANGO_TO_STR_TYPE,
+    DevState,
+)
+from .tangodatabase import (
+    TangoInfo,
+    TangoAttrInfo,
+    TangoDevInfo,
+    TangoServInfo,
+    TangoDevClassInfo,
+    TangoDatabaseCache,
+    TangoDatabase,
+    TangoAuthority,
+)
+from .tangodevice import TangoDevice
+from .tangofactory import TangoFactory
+from .tangoattribute import (
+    TangoAttribute,
+    TangoAttributeEventListener,
+    TangoAttrValue,
+)
+from .tangoconfiguration import TangoConfiguration
 
 
+__all__ = [
+    "TangoObjectType",
+    "EVENT_TO_POLLING_EXCEPTIONS",
+    "FROM_TANGO_TO_NUMPY_TYPE",
+    "FROM_TANGO_TO_STR_TYPE",
+    "DevState",
+    "TangoInfo",
+    "TangoAttrInfo",
+    "TangoDevInfo",
+    "TangoServInfo",
+    "TangoDevClassInfo",
+    "TangoDatabaseCache",
+    "TangoDatabase",
+    "TangoAuthority",
+    "TangoDevice",
+    "TangoFactory",
+    "TangoAttribute",
+    "TangoAttributeEventListener",
+    "TangoAttrValue",
+    "TangoConfiguration",
+]
 __docformat__ = "restructuredtext"
