@@ -1,40 +1,34 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
-"""This module provides a set of basic Taurus widgets based on QLed"""
-from __future__ import absolute_import
-
-from builtins import str
-from builtins import object
+"""This module provides a set of basic Taurus widgets based on QLed
+"""
 
 import weakref
-try:
-    from collections.abc import Sequence
-except ImportError:  # bck-compat py 2.7
-    from collections import Sequence
+from collections.abc import Sequence
 
 from taurus.external.qt import Qt
 
@@ -44,31 +38,32 @@ from taurus.qt.qtgui.base import TaurusBaseWidget
 from .qled import QLed
 
 
-__all__ = ["TaurusLed"]
-
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 _QT_PLUGIN_INFO = {
-    'module': 'taurus.qt.qtgui.display',
-    'group': 'Taurus Display',
-    'icon': "designer:ledgreen.png",
+    "module": "taurus.qt.qtgui.display",
+    "group": "Taurus Display",
+    "icon": "designer:ledgreen.png",
 }
 
 
 class _TaurusLedController(object):
 
     #            key     status,     color, inTrouble
-    LedMap = {True: (True,    "green",    False),
-              False: (False,    "black",    False),
-              None: (False,    "black",     True)}
+    LedMap = {
+        True: (True, "green", False),
+        False: (False, "black", False),
+        None: (False, "black", True),
+    }
 
     LedQualityMap = {
-        AttrQuality.ATTR_ALARM: (True,   "orange",    False),
-        AttrQuality.ATTR_CHANGING: (True,     "blue",    False),
-        AttrQuality.ATTR_INVALID: (True,      "red",    False),
-        AttrQuality.ATTR_VALID: (True,    "green",    False),
-        AttrQuality.ATTR_WARNING: (True,   "orange",    False),
-        None: (False,    "black",     True)}
+        AttrQuality.ATTR_ALARM: (True, "orange", False),
+        AttrQuality.ATTR_CHANGING: (True, "blue", False),
+        AttrQuality.ATTR_INVALID: (True, "red", False),
+        AttrQuality.ATTR_VALID: (True, "green", False),
+        AttrQuality.ATTR_WARNING: (True, "orange", False),
+        None: (False, "black", True),
+    }
 
     def __init__(self, widget):
         self._widget = weakref.ref(widget)
@@ -83,11 +78,11 @@ class _TaurusLedController(object):
         widget, obj = self.widget(), self.modelObj()
         fgRole = widget.fgRole
         value = None
-        if fgRole == 'rvalue':
+        if fgRole == "rvalue":
             value = obj.rvalue
-        elif fgRole == 'wvalue':
+        elif fgRole == "wvalue":
             value = obj.wvalue
-        elif fgRole == 'quality':
+        elif fgRole == "quality":
             return obj.quality
 
         # handle 1D and 2D values
@@ -97,7 +92,7 @@ class _TaurusLedController(object):
                 for i in idx:
                     value = value[i]
 
-        return bool(value)
+        return value if value is None else bool(value)
 
     def usePreferedColor(self, widget):
         return True
@@ -118,13 +113,13 @@ class _TaurusLedController(object):
         except Exception:
             pass
         ledMap = self.LedMap
-        if widget.fgRole == 'quality':
+        if widget.fgRole == "quality":
             ledMap = self.LedQualityMap
         try:
             status, color, trouble = ledMap[key]
-        except:
+        except Exception:
             status, color, trouble = False, "red", True
-        if self.usePreferedColor(widget):
+        if self.usePreferedColor(widget) and not trouble:
             if status:
                 color = widget.onColor
             else:
@@ -146,54 +141,57 @@ class _TaurusLedController(object):
 
 
 class _TaurusLedControllerBool(_TaurusLedController):
-
     def usePreferedColor(self, widget):
         # use prefered widget color if representing the boolean read or write
         # value. If representing the quality, use the quality map
-        return widget.fgRole != 'quality'
+        return widget.fgRole != "quality"
+
 
 try:
     from taurus.core.tango import DevState  # TODO: Tango-centric
+
     class _TaurusLedControllerState(_TaurusLedController):
 
         #                key      status,       color, inTrouble
-        LedMap = {DevState.ON: (True,    "green",    False),
-                  DevState.OFF: (False,    "black",    False),
-                  DevState.CLOSE: (True,    "white",    False),
-                  DevState.OPEN: (True,    "green",    False),
-                  DevState.INSERT: (True,    "green",    False),
-                  DevState.EXTRACT: (True,    "green",    False),
-                  DevState.MOVING: (True,     "blue",    False),
-                  DevState.STANDBY: (True,   "yellow",    False),
-                  DevState.FAULT: (True,      "red",    False),
-                  DevState.INIT: (True,   "yellow",    False),
-                  DevState.RUNNING: (True,     "blue",    False),
-                  DevState.ALARM: (True,   "orange",    False),
-                  DevState.DISABLE: (True,  "magenta",    False),
-                  DevState.UNKNOWN: (False,    "black",    False),
-                  None: (False,    "black",     True)}
+        LedMap = {
+            DevState.ON: (True, "green", False),
+            DevState.OFF: (False, "black", False),
+            DevState.CLOSE: (True, "white", False),
+            DevState.OPEN: (True, "green", False),
+            DevState.INSERT: (True, "green", False),
+            DevState.EXTRACT: (True, "green", False),
+            DevState.MOVING: (True, "blue", False),
+            DevState.STANDBY: (True, "yellow", False),
+            DevState.FAULT: (True, "red", False),
+            DevState.INIT: (True, "yellow", False),
+            DevState.RUNNING: (True, "blue", False),
+            DevState.ALARM: (True, "orange", False),
+            DevState.DISABLE: (True, "magenta", False),
+            DevState.UNKNOWN: (False, "black", False),
+            None: (False, "black", True),
+        }
 
         def value(self):
             widget, obj = self.widget(), self.modelObj()
             fgRole = widget.fgRole
             value = None
-            if fgRole == 'rvalue':
+            if fgRole == "rvalue":
                 value = obj.rvalue
-            elif fgRole == 'wvalue':
+            elif fgRole == "wvalue":
                 value = obj.wvalue
-            elif fgRole == 'quality':
+            elif fgRole == "quality":
                 value = obj.quality
             return value
 
         def usePreferedColor(self, widget):
             # never use prefered widget color. Use always the map
             return False
-except:
+
+except Exception:
     pass
 
 
 class _TaurusLedControllerDesignMode(_TaurusLedController):
-
     def _updateDisplay(self, widget):
         widget.ledStatus = True
         if widget.ledStatus:
@@ -208,20 +206,21 @@ class _TaurusLedControllerDesignMode(_TaurusLedController):
 
 class TaurusLed(QLed, TaurusBaseWidget):
     """A widget designed to represent with a LED image the state of a device,
-    the value of a boolean attribute or the quality of an attribute."""
+    the value of a boolean attribute or the quality of an attribute.
+    """
 
     DefaultModelIndex = None
-    DefaultFgRole = 'rvalue'
+    DefaultFgRole = "rvalue"
     DefaultOnColor = "green"
-    DefaultOffColor = "black"
+    DefaultOffColor = "green"
 
-    _deprecatedRoles = dict(value='rvalue', w_value='wvalue')
+    _deprecatedRoles = dict(value="rvalue", w_value="wvalue")
 
     def __init__(self, parent=None, designMode=False):
         name = self.__class__.__name__
         self._designMode = designMode
         self._modelIndex = self.DefaultModelIndex
-        self._modelIndexStr = ''
+        self._modelIndexStr = ""
         self._fgRole = self.DefaultFgRole
         self._onColor = self.DefaultOnColor
         self._offColor = self.DefaultOffColor
@@ -229,10 +228,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
         self.call__init__wo_kw(QLed, parent)
         self.call__init__(TaurusBaseWidget, name, designMode=designMode)
 
-        # if we are in design mode there will be no events so we force the
-        # creation of a controller object
-        if self._designMode:
-            self.controller().update()
+        self.controller().update()
 
     def _calculate_controller_class(self):
         model = self.getModelObj()
@@ -262,9 +258,9 @@ class TaurusLed(QLed, TaurusBaseWidget):
         self._controller = ctrl = ctrl_klass(self)
         return ctrl
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # TaurusBaseWidget overwriting
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def handleEvent(self, evt_src, evt_type, evt_value):
         self.controller().handleEvent(evt_src, evt_type, evt_value)
@@ -277,9 +273,9 @@ class TaurusLed(QLed, TaurusBaseWidget):
         self._controller = None
         TaurusBaseWidget.setModel(self, m)
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # QT property definition
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def getFgRole(self):
         return self._fgRole
@@ -287,8 +283,11 @@ class TaurusLed(QLed, TaurusBaseWidget):
     def setFgRole(self, fgRole):
         role = self._deprecatedRoles.get(fgRole, fgRole)
         if fgRole != role:
-            self.deprecated(rel='4.0', dep='setFgRole(%s)' % fgRole,
-                            alt='setFgRole(%s)' % role)
+            self.deprecated(
+                rel="4.0",
+                dep="setFgRole(%s)" % fgRole,
+                alt="setFgRole(%s)" % role,
+            )
         self._fgRole = str(role)
         self.controller().update()
 
@@ -298,13 +297,16 @@ class TaurusLed(QLed, TaurusBaseWidget):
     def getOnColor(self):
         """Returns the preferred led on color
         :return: led on color
-        :rtype: str"""
+        :rtype: str
+        """
         return self._onColor
 
     def setOnColor(self, color):
         """Sets the preferred led on color
+
         :param status: the new on color
-        :type  status: str"""
+        :type  status: str
+        """
         color = str(color).lower()
         if not self.isLedColorValid(color):
             raise Exception("Invalid color '%s'" % color)
@@ -318,13 +320,16 @@ class TaurusLed(QLed, TaurusBaseWidget):
     def getOffColor(self):
         """Returns the preferred led off color
         :return: led off color
-        :rtype: str"""
+        :rtype: str
+        """
         return self._offColor
 
     def setOffColor(self, color):
         """Sets the preferred led off color
+
         :param status: the new off color
-        :type  status: str"""
+        :type  status: str
+        """
         color = str(color).lower()
         if not self.isLedColorValid(color):
             raise Exception("Invalid color '%s'" % color)
@@ -348,10 +353,10 @@ class TaurusLed(QLed, TaurusBaseWidget):
         else:
             try:
                 mi_value = eval(str(mi))
-            except:
+            except Exception:
                 return
             if type(mi_value) == int:
-                mi_value = mi_value,
+                mi_value = (mi_value,)
             if not isinstance(mi_value, Sequence):
                 return
             self._modelIndex = mi_value
@@ -378,8 +383,12 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusBaseWidget.resetModel`
     #:
     #: .. seealso:: :ref:`model-concept`
-    model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel, setModel,
-                            TaurusBaseWidget.resetModel)
+    model = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getModel,
+        setModel,
+        TaurusBaseWidget.resetModel,
+    )
 
     #: This property holds whether or not this widget should search in the
     #: widget hierarchy for a model prefix in a parent widget.
@@ -391,9 +400,12 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusBaseWidget.resetUseParentModel`
     #:
     #: .. seealso:: :ref:`model-concept`
-    useParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel,
-                                     TaurusBaseWidget.setUseParentModel,
-                                     TaurusBaseWidget.resetUseParentModel)
+    useParentModel = Qt.pyqtProperty(
+        "bool",
+        TaurusBaseWidget.getUseParentModel,
+        TaurusBaseWidget.setUseParentModel,
+        TaurusBaseWidget.resetUseParentModel,
+    )
 
     #: This property holds the index inside the model value that should be
     #: displayed
@@ -405,8 +417,9 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.resetModelIndex`
     #:
     #: .. seealso:: :ref:`model-concept`
-    modelIndex = Qt.pyqtProperty("QString", getModelIndex, setModelIndex,
-                                 resetModelIndex)
+    modelIndex = Qt.pyqtProperty(
+        "QString", getModelIndex, setModelIndex, resetModelIndex
+    )
 
     #: This property holds the foreground role.
     #: Valid values are:
@@ -420,8 +433,9 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.getFgRole`
     #:     * :meth:`TaurusLed.setFgRole`
     #:     * :meth:`TaurusLed.resetFgRole`
-    fgRole = Qt.pyqtProperty("QString", getFgRole, setFgRole,
-                             resetFgRole, doc="foreground role")
+    fgRole = Qt.pyqtProperty(
+        "QString", getFgRole, setFgRole, resetFgRole, doc="foreground role"
+    )
 
     #: This property holds the preferred led color
     #: This value is used for the cases where the model value does not contain
@@ -435,8 +449,13 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.getOnColor`
     #:     * :meth:`TaurusLed.setOnColor`
     #:     * :meth:`TaurusLed.resetOnColor`
-    onColor = Qt.pyqtProperty("QString", getOnColor, setOnColor, resetOnColor,
-                              doc="preferred led On color")
+    onColor = Qt.pyqtProperty(
+        "QString",
+        getOnColor,
+        setOnColor,
+        resetOnColor,
+        doc="preferred led On color",
+    )
 
     #: This property holds the preferred led color
     #: This value is used for the cases where the model value does not contain
@@ -450,19 +469,26 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.getOffColor`
     #:     * :meth:`TaurusLed.setOffColor`
     #:     * :meth:`TaurusLed.resetOffColor`
-    offColor = Qt.pyqtProperty("QString", getOffColor, setOffColor, resetOffColor,
-                               doc="preferred led Off color")
+    offColor = Qt.pyqtProperty(
+        "QString",
+        getOffColor,
+        setOffColor,
+        resetOffColor,
+        doc="preferred led Off color",
+    )
 
 
 def demo():
     "Led"
     from .demo import taurusleddemo
+
     return taurusleddemo.main()
 
 
 def main():
     import sys
     import taurus.qt.qtgui.application
+
     Application = taurus.qt.qtgui.application.TaurusApplication
 
     app = Application.instance()
@@ -470,11 +496,17 @@ def main():
 
     if owns_app:
         import taurus.core.util.argparse
+
         parser = taurus.core.util.argparse.get_taurus_parser()
         parser.usage = "%prog [options] <full_attribute_name(s)>"
-        app = Application(sys.argv, cmd_line_parser=parser,
-                          app_name="Taurus led demo", app_version="1.0",
-                          org_domain="Taurus", org_name="Tango community")
+        app = Application(
+            sys.argv,
+            cmd_line_parser=parser,
+            app_name="Taurus led demo",
+            app_version="1.0",
+            org_domain="Taurus",
+            org_name="Tango community",
+        )
 
     args = app.get_command_line_args()
 
@@ -497,5 +529,6 @@ def main():
     else:
         return w
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
